From d09927d74224269362f7c30f6702c9d5194bfe8b Mon Sep 17 00:00:00 2001
From: Alyssa Rosenzweig <alyssa@collabora.com>
Date: Mon, 1 Mar 2021 16:01:22 +0000
Subject: [PATCH] panfrost/lcra: Fix constraint counting

We need to iterate the whole row, we can't be clever and only look at
one side, the symmetry doesn't work like that. See the original paper.

Fixes: 66ad64d73d2 ("pan/midgard: Implement linearly-constrained register allocation")
Signed-off-by: Alyssa Rosenzweig <alyssa@collabora.com>
---
 src/panfrost/util/lcra.c | 4 +---
 1 file changed, 1 insertion(+), 3 deletions(-)

diff --git a/src/panfrost/util/lcra.c b/src/panfrost/util/lcra.c
index 49652829a48..45cff37e61f 100644
--- a/src/panfrost/util/lcra.c
+++ b/src/panfrost/util/lcra.c
@@ -207,15 +207,13 @@ lcra_set_node_spill_cost(struct lcra_state *l, unsigned node, signed cost)
                 l->spill_cost[node] = cost;
 }
 
-/* Count along the lower triangle */
-
 static unsigned
 lcra_count_constraints(struct lcra_state *l, unsigned i)
 {
         unsigned count = 0;
         unsigned *constraints = &l->linear[i * l->node_count];
 
-        for (unsigned j = 0; j < i; ++j)
+        for (unsigned j = 0; j < l->node_count; ++j)
                 count += util_bitcount(constraints[j]);
 
         return count;
-- 
2.30.0

